@@ -313,8 +313,8 @@ class DatabaseOverviewMetricGroup(MetricGroupDef):
             )
 
             total_sys_hit = (
-                "{total_read} - sum(sub.reads)"
-                "/ greatest(extract(epoch FROM sub.mesure_interval), 1)"
+                "greatest({total_read} - sum(sub.reads)"
+                "/ greatest(extract(epoch FROM sub.mesure_interval), 1),0)"
                 " AS total_sys_hit"
                 "".format(total_read=total_read("sub", True))
             )
@@ -368,6 +368,7 @@ class DatabasePGSAOverview(MetricGroupDef):
 
     name = "pgsa"
     xaxis = "ts"
+    desc = "All backends, except autovacuum workers, are included"
     data_url = r"/server/(\d+)/metrics/pgsa_overview/([^\/]+)/"
     backend_xid_age = MetricDef(label="Backend xid age")
     backend_xmin_age = MetricDef(label="Backend xmin age")
@@ -399,14 +400,14 @@ class DatabasePGSAOverview(MetricGroupDef):
     @property
     def query(self):
         query = powa_get_pgsa_sample(per_db=True)
-
+        # Those greatests are to avoid having negative values returned, see https://github.com/powa-team/powa-archivist/issues/98
         cols = [
             "extract(epoch FROM ts) AS ts",
-            "max(backend_xid_age) AS backend_xid_age",
-            "max(backend_xmin_age) AS backend_xmin_age",
-            "max(backend_start_age) FILTER (WHERE datid IS NOT NULL) AS oldest_backend",
-            "max(xact_start_age) FILTER (WHERE datid IS NOT NULL) AS oldest_xact",
-            "max(query_start_age) FILTER (WHERE datid IS NOT NULL) AS oldest_query",
+            "greatest(max(backend_xid_age),0) AS backend_xid_age",
+            "greatest(max(backend_xmin_age),0) AS backend_xmin_age",
+            "greatest(max(backend_start_age) FILTER (WHERE datid IS NOT NULL),0) AS oldest_backend",
+            "greatest(max(xact_start_age) FILTER (WHERE datid IS NOT NULL),0) AS oldest_xact",
+            "greatest(max(query_start_age) FILTER (WHERE datid IS NOT NULL AND state !~ 'idle'),0) AS oldest_query",
             "count(*) FILTER (WHERE state = 'idle') AS nb_idle",
             "count(*) FILTER (WHERE state = 'active') AS nb_active",
             "count(*) FILTER (WHERE state = 'idle in transaction') AS nb_idle_xact",
@@ -1083,6 +1084,7 @@ class DatabaseOverview(DashboardPage):
                 Graph(
                     "Global activity (On database %(database)s)",
                     metrics=pgsa_metrics[0],
+                    desc=DatabasePGSAOverview.desc,
                     renderer="bar",
                     stack=True,
                 )
@@ -1099,6 +1101,7 @@ class DatabaseOverview(DashboardPage):
             Graph(
                 "Backend age (On database %(database)s)",
                 metrics=pgsa_metrics[1],
+                desc=DatabasePGSAOverview.desc,
             )
         )
 
